@@ -7,8 +7,7 @@ import os
 from django.db import models
 from django import forms
 from django.forms.widgets import Input
-from django.db.models.fields import Field, CharField
-from django.utils.encoding import force_unicode
+from django.db.models.fields import Field
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 
@@ -120,4 +119,8 @@ class FileBrowseField(Field):
         defaults.update(kwargs)
         return super(FileBrowseField, self).formfield(**defaults)
 
-
+try:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^filebrowser\.fields\.FileBrowseField"])
+except ImportError:
+    pass
